%% Petrophysik bung 1
% vom Dummdepp
clear
clc


%% Daten importieren & umrechnen
data = csvread('TriaxialTests.csv',1);

PForce = data(:,1);             % Piston force [kN]
CPressure = data(:,2);          % Confining pressure [bar]

diameter = 4;                   % Proben-Durchmesser [cm]
area = pi*(diameter/100/2)^2;   % Oberflcheninhalt [m^2]

sigma1 = (PForce./area) ./1000; % kN in MPa umrechnen
sigma3 = CPressure .* 0.1;      % bar in MPa umrechnen


%% Mohr-Kreise berechnen und plotten

N = length(sigma1);             % Anzahl der Messungen
gridpoints = 100;               % 100 Punkte fr jeden Kreis
phi = linspace(0,pi,gridpoints);
phi = phi';

% Arrays initialisieren
centers = zeros(1,N);           % Mittelpunkte der Kreise
X = zeros(gridpoints,N);        % X-Koordinaten der Punkte
Y = zeros(gridpoints,N);        % Y-Koordinaten der Punkte

% Kreis-Punkte berechnen
for i = 1:N
   centers(i) =  ((sigma1(i) - sigma3(i)) / 2) + sigma3(i);
   radius = (sigma1(i) - sigma3(i)) / 2;
   X(:,i) = radius * cos(phi);
   Y(:,i) = radius * sin(phi);
end

% Mohr-Kreise plotten
for i = 1:N
    figure(1)
    hold on
    plot(X(:,i)+centers(i),Y(:,i),'blue')
    plot(centers(i),0,'*')
end
axis equal
grid on
title('Mohr-Kreise')
xlabel('Normal stress [MPa]')
ylabel('Shear stress [Mpa]')
ylim([0 70])
xlim([0 max(sigma1)])


%% Maximale Drcke finden

maxSig1 = max(sigma1);  % maximaler Sigma 1 Wert [MPa]
maxSig3 = max(sigma3);  % maximaler Sigma 3 Wert [MPa]
